var searchData=
[
  ['c_20utilities_0',['C++ utilities',['../index.html',1,'']]],
  ['clangd_1',['clangd',['../index.html#autotoc_md13',1,'']]],
  ['cmake_20arguments_2',['Variables passable as CMake arguments',['../md_doc_2buildvariables.html#autotoc_md33',1,'']]],
  ['cmake_20itself_3',['Useful variables provided by CMake itself',['../md_doc_2buildvariables.html#autotoc_md34',1,'']]],
  ['cmake_20presets_4',['CMake presets',['../index.html#autotoc_md16',1,'']]],
  ['code_5',['Using Visual Studio Code',['../index.html#autotoc_md12',1,'']]],
  ['configuration_6',['Metadata and overall project configuration',['../md_doc_2buildvariables.html#autotoc_md41',1,'']]],
  ['copyright_20notice_20and_20license_7',['Copyright notice and license',['../index.html#autotoc_md31',1,'']]],
  ['custom_20variables_8',['Custom variables',['../md_doc_2buildvariables.html#autotoc_md35',1,'']]]
];
